# VTK and openCARP helper methods

This project builds a collection of often used methods used for encapsulating the vtk python package, openCARP file conversion and 
additional methods from AugmentA to improve the flow in python based cardiac modeling environments. 

Package available with

`pip install vtk-openCARP-methods-ibt`

# Structure Overview

## Advanced documentation

You can find the full documentation at https://vtk-opencarp-methods-ibt.readthedocs.io/en/latest/

## AugmentA_methods

Methods associated with AugmentA development

## mathematical_operations
Some vector operations

## openCARP

openCARP based methods. Currently only includes conversion to .pts .elem and .lon files

## vtk_methods

Number of methods which encapsulates the vtk library to simplify the application of filers and read/write operations.  